
.. py:currentmodule:: pythreejs

BufferAttribute
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: BufferAttribute(array=None, normalized=True, )
    :members:
    :undoc-members:

    This widget has some manual overrides on the Python side.

    Inherits :py:class:`~pythreejs.ThreeWidget`.

    Three.js docs: https://threejs.org/docs/#api/core/BufferAttribute


    .. py:attribute:: array

        .. sourcecode:: python

            WebGLDataUnion().tag(sync=True)

    .. py:attribute:: dynamic

        .. sourcecode:: python

            Bool(False, allow_none=False).tag(sync=True)

    .. py:attribute:: needsUpdate

        .. sourcecode:: python

            Bool(False, allow_none=False).tag(sync=True)

    .. py:attribute:: normalized

        .. sourcecode:: python

            Bool(True, allow_none=False).tag(sync=True)

    .. py:attribute:: version

        .. sourcecode:: python

            CInt(-1, allow_none=False).tag(sync=True)

